<?php
namespace Teknisa\PLA\Services;

use Zeedhi\Framework\DataSource\ParameterBag;
use \Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Pla00500ConsumoPorServicoService {
	protected $connection;
	protected $environment;

	public function __construct($connection, $environment){
		$this->connection = $connection;
		$this->environment = $environment;
	}

	protected function execute($sql, $params){
		$query = $this->connection->prepare($sql);
    	$query->execute($params);
	}

	public function operation($row, $idtipocons){
		
		$sql = "INSERT INTO CONSSERV
				   (CDFILIAL,
				    CDSERVFILI,
				    IDQTDECONS,
				    IDTIPOCONS,
				    DTCONSSERV,
				    CDPRODUTO,
				    QTCONSSERV,
				    IDPRODCONSFPE,
				    IDTPREQPROD)
				(SELECT
				    lpad(:P_CDFILIGRAVA, 4, '0'),
				    lpad(:P_CDSERVGRAVA, 5, '0'),
				    IDQTDECONS,
				    :P_IDTIPOCONSGRAVA,
				    :P_DTCONSSERVGRAVA,
				    CDPRODUTO,
				    QTCONSSERV,
				    IDPRODCONSFPE,
				    IDTPREQPROD
				 FROM
				    CONSSERV
				 WHERE
				    (CDFILIAL   = :P_CDFILIORIG)          AND
				    (CDSERVFILI = :P_CDSERVORIG)          AND
				    (IDQTDECONS = :P_IDQTDECONS)          AND
				    (IDTIPOCONS = :P_IDTIPOCONS)          AND
				    (DTCONSSERV = :P_DTCONSSERV)          AND
				    (INSTR(:P_CDPRODUTO, CDPRODUTO) <> 0) AND
				    (CDPRODUTO NOT IN (SELECT
				                          CDPRODUTO
				                       FROM
				                          CONSSERV
				                       WHERE
				                          CDFILIAL   = :P_CDFILIGRAVA     AND
				                          CDSERVFILI = :P_CDSERVGRAVA     AND
				                          IDQTDECONS = :P_IDQTDECONS      AND
				                          IDTIPOCONS = :P_IDTIPOCONSGRAVA AND
				                          DTCONSSERV = :P_DTCONSSERVGRAVA))
				 )";

		$params = array(
			  'P_CDFILIGRAVA' => $row['P_CDFILIGRAVA'],
		      'P_CDSERVGRAVA' => $row['P_CDSERVGRAVA'],
		      'P_IDTIPOCONSGRAVA' => $idtipocons,
		      'P_DTCONSSERVGRAVA' => $row['P_DTCONSSERVGRAVA'],
		      'P_CDFILIORIG' => $row['P_CDFILIORIG'],
		      'P_CDSERVORIG' => $row['P_CDSERVORIG'],
		      'P_IDQTDECONS' => $row['P_IDQTDECONS'],
		      'P_IDTIPOCONS' => $row['P_IDTIPOCONS'],
		      'P_DTCONSSERV' => $row['P_DTCONSSERV'],
		      'P_CDPRODUTO'  => $row['P_CDPRODUTO']
		);
		$this->execute($sql, $params);

	}

	public function deleteFromSubscribe($row, $idtipocons){
		try{
			$sql = "DELETE FROM CONSSERV
					WHERE
					(NRORG      = :P_NRORG)   		  AND
					(CDFILIAL   = :P_CDFILIGRAVA)     AND
					(CDSERVFILI = :P_CDSERVGRAVA)     AND
				    (DTCONSSERV = :P_DTCONSSERVGRAVA) AND
                    (IDQTDECONS = :P_IDQTDECONS)      AND
                    (IDTIPOCONS = :P_IDTIPOCONSGRAVA)";

			$params = array(
					'P_CDFILIGRAVA'     => $row['P_CDFILIGRAVA'],
					'P_CDSERVGRAVA'     => $row['P_CDSERVGRAVA'],
					'P_IDTIPOCONSGRAVA' => $idtipocons,
					'P_DTCONSSERVGRAVA' => $row['P_DTCONSSERVGRAVA'],
					'P_IDQTDECONS'      => $row['P_IDQTDECONS'],
					'P_NRORG'           => $this->environment->getNrOrg()
			);

			$this->execute($sql, $params);
		}catch(\Exception $e){
			throw $e;
		}
 	}

 	public function insertToReplace($row, $prodDest, $dtconsserv){
 		$sql = "INSERT INTO CONSSERV
									  (CDFILIAL,
									   CDSERVFILI,
									   IDQTDECONS,
									   IDTIPOCONS,
									   DTCONSSERV,
									   CDPRODUTO,
									   QTCONSSERV)
									(SELECT
									   CDFILIAL,
									   CDSERVFILI,
									   IDQTDECONS,
									   IDTIPOCONS,
									   DTCONSSERV,
									   TRIM(LPAD(:P_CDPRODDEST, 10, ' ')),
									   QTCONSSERV
									 FROM CONSSERV
									 WHERE
									   CDFILIAL   = :P_CDFILIAL AND
									   CDSERVFILI = :P_CDSERVFILI AND
									   IDQTDECONS = :P_IDQTDECONS AND
									   IDTIPOCONS = :P_IDTIPOCONS AND
									   DTCONSSERV = :P_DTCONSSERV AND
									   CDPRODUTO  = :P_CDPRODORIG AND
									   NOT EXISTS
									   (SELECT CDPRODUTO
									    FROM CONSSERV
									    WHERE
									       CDFILIAL   = :P_CDFILIAL AND
									       CDSERVFILI = :P_CDSERVFILI AND
									       IDQTDECONS = :P_IDQTDECONS AND
									       IDTIPOCONS = :P_IDTIPOCONS AND
									       DTCONSSERV = :P_DTCONSSERV AND
									       CDPRODUTO  = :P_CDPRODDEST) )";

 		$params = array(
 			'P_CDPRODDEST' => $prodDest,
			'P_CDFILIAL' => $row['CDFILIAL'],
			'P_CDSERVFILI' => $row['CDSERVFILI'],
			'P_IDQTDECONS' => $row['IDQTDECONS'],
			'P_IDTIPOCONS' => $row['IDTIPOCONS'],
			'P_DTCONSSERV' => $dtconsserv,
			'P_CDPRODORIG' => $row['CDPRODUTO']
 		);
 		$this->execute($sql, $params);
 	}

 	public function deleteOldProductToReplace($row, $dtconsserv){
 			$sql = "DELETE FROM CONSSERV
							WHERE
  						CDFILIAL = :OLD_CDFILIAL and
  						CDSERVFILI = :OLD_CDSERVFILI and
  						IDQTDECONS = :OLD_IDQTDECONS and
  						IDTIPOCONS = :OLD_IDTIPOCONS and
  						DTCONSSERV = :OLD_DTCONSSERV and
  						CDPRODUTO = :OLD_CDPRODUTO";
  		$params = array(
  			'OLD_CDFILIAL' => $row['CDFILIAL'],
				'OLD_CDSERVFILI' => $row['CDSERVFILI'],
				'OLD_IDQTDECONS' => $row['IDQTDECONS'],
				'OLD_IDTIPOCONS' => $row['IDTIPOCONS'],
				'OLD_DTCONSSERV' => $dtconsserv,
				'OLD_CDPRODUTO' => $row['CDPRODUTO']
  		);
  		$this->execute($sql, $params);
 	}

}